Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3264)

Unified Diff: ash/common/wm_shell.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/wm_shell.h
diff --git a/ash/common/wm_shell.h b/ash/common/wm_shell.h
index c6d79223af4be922fcb710e55588198f06ec9d36..f1e45ddbce596a8747ffe99b4acec116719004d6 100644
--- a/ash/common/wm_shell.h
+++ b/ash/common/wm_shell.h
@@ -34,7 +34,7 @@ class Insets;
class Point;
}
-namespace shell {
+namespace service_manager {
class Connector;
}
@@ -181,7 +181,7 @@ class ASH_EXPORT WmShell {
return window_selector_controller_.get();
}
// Returns true when ash is running as a shell::Service.
virtual bool IsRunningInMash() const = 0;
virtual WmWindow* NewWindow(ui::wm::WindowType window_type,
« no previous file with comments | « ash/common/system/tray/system_tray_controller.cc ('k') | ash/mus/accelerators/accelerator_controller_delegate_mus.h » ('j') | no next file with comments »
@@ -181,7 +181,7 @@ class ASH_EXPORT WmShell {
return window_selector_controller_.get();
}
- // Returns true when ash is running as a shell::Service.
+ // Returns true when ash is running as a service_manager::Service.
virtual bool IsRunningInMash() const = 0;
virtual WmWindow* NewWindow(ui::wm::WindowType window_type,

Powered by Google App Engine
This is Rietveld 408576698